@@ -17,6 +17,13 @@ def first_day_of_week(any_day:datetime.date) -> datetime.date:
     return any_day - datetime.timedelta(days=any_day.weekday())
 
 
+def first_day_of_last_month(any_day:datetime.date=None) -> datetime.date:
+    if any_day is None:
+        any_day = datetime.date.today()
+
+    return (any_day.replace(day=1) - datetime.timedelta(days=1)).replace(day=1)
+
+
 def last_day_of_last_month(any_day:datetime.date=None) -> datetime.date:
     if any_day is None:
         any_day = datetime.date.today()
